API
====

Package ``abilian``
-------------------

Module :mod:`abilian.app`
^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.app

Module :mod:`abilian.i18n`
^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: abilian.i18n

   .. autodata:: _
   .. autodata:: _l
   .. autodata:: _n
   .. autoclass:: Babel
       :show-inheritance:
       :no-undoc-members:
   .. autodata:: babel


Package ``abilian.core``
------------------------

Module :mod:`abilian.core.commands`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.core.commands

Module :mod:`abilian.core.entities`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.core.entities

   .. autoclass:: Entity
      :show-inheritance:
      :members:
      :special-members:


Module :mod:`abilian.core.extensions`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.core.extensions

Module :mod:`abilian.core.logging`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.core.logging


Module :mod:`abilian.core.signals`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.core.signals

Module :mod:`abilian.core.sqlalchemy`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.core.sqlalchemy

Module :mod:`abilian.core.models`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.core.models.base
.. automodule:: abilian.core.models.subjects
.. automodule:: abilian.core.models.owned
.. automodule:: abilian.core.models.blob
.. automodule:: abilian.core.models.tag
.. automodule:: abilian.core.models.comment
.. automodule:: abilian.core.models.attachment
.. automodule:: abilian.core.models

Module :mod:`abilian.core.util`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.core.util

Package ``abilian.services``
----------------------------

Module :mod:`abilian.services.base`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.services.base

Module :mod:`abilian.services.activity`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.services.activity


Module :mod:`abilian.services.audit`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.services.audit

Module :mod:`abilian.services.conversion`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.services.conversion

Module :mod:`abilian.services.image`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.services.image

Module :mod:`abilian.services.indexing`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autodata:: abilian.services.indexing.service
   :annotation:

.. autoclass:: abilian.services.indexing.service.WhooshIndexService
.. autofunction:: abilian.services.indexing.indexable_role

Module :mod:`abilian.services.security`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autodata:: abilian.services.security.service
   :annotation:

.. autoclass:: abilian.services.security.service.SecurityServiceState
.. autodata:: abilian.services.security.Anonymous
   :annotation:
.. autodata:: abilian.services.security.Authenticated
   :annotation:


Package ``abilian.web``
-----------------------

Module :mod:`abilian.web.attachments`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.web.attachments


Module :mod:`abilian.web.comments`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.web.comments


Module :mod:`abilian.web.filters`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.web.filters

Module :mod:`abilian.web.action`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.web.action

   .. autoclass:: ActionRegistry
      :members:
      :undoc-members:

Module :mod:`abilian.web.nav`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.web.nav

Module :mod:`abilian.web.forms`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.web.forms

Module :mod:`abilian.web.views`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.web.views

Module :mod:`abilian.web.frontend`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.web.frontend

Module :mod:`abilian.web.tags`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.web.tags


Module :mod:`abilian.web.util`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: abilian.web.util


Package ``abilian.testing``
---------------------------

.. automodule:: abilian.testing
